Documentation
¶
Overview ¶
Package limiter defines rate limiting systems.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrStopped = fmt.Errorf("store is stopped")
ErrStopped is the error returned when the store is stopped. All implementers should return this error for stoppable stores.
Functions ¶
This section is empty.
Types ¶
type Store ¶
type Store interface {
// Take takes a token from the given key if available, returning:
//
// - the configured limit size
// - the number of remaining tokens in the interval
// - the server time when new tokens will be available
// - whether the take was successful
// - any errors that occurred while performing the take - these should be
// backend errors (e.g. connection failures); Take() should never return an
// error for an bucket.
//
// If "ok" is false, the take was unsuccessful and the caller should NOT
// service the request.
//
// See the note about keys on the interface documentation.
Take(ctx context.Context, key string) (tokens, remaining, reset uint64, ok bool, err error)
// Set configures the limit at the provided key. If a limit already exists, it
// is overwritten. This also sets the number of tokens in the bucket to the
// limit.
Set(ctx context.Context, key string, tokens uint64, interval time.Duration) error
// Close terminates the store and cleans up any data structures or connections
// that may remain open. After a store is stopped, Take() should always return
// zero values.
Close(ctx context.Context) error
}
Store is an interface for limiter storage backends.
Keys should be hash, sanitized, or otherwise scrubbed of identifiable information they will be given to the store in plaintext. If you're rate limiting by IP address, for example, the IP address would be stored in the storage system in plaintext. This may be undesirable in certain situations, like when the store is a public database. In those cases, you should hash or HMAC the key before passing giving it to the store. If you want to encrypt the value, you must use homomorphic encryption to ensure the value always encrypts to the same ciphertext.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package httplimit provides middleware for rate limiting HTTP handlers.
|
Package httplimit provides middleware for rate limiting HTTP handlers. |
|
internal
|
|
|
fasttime
Package fasttime gets wallclock time, but super fast.
|
Package fasttime gets wallclock time, but super fast. |
|
Package memorystore defines an in-memory storage system for limiting.
|
Package memorystore defines an in-memory storage system for limiting. |
|
Package noopstore defines a storage system for limiting that always allows requests.
|
Package noopstore defines a storage system for limiting that always allows requests. |
|
tools
module
|